# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-01-06 01:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('thorson_wiki', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='article',
            name='login_required',
        ),
        migrations.AddField(
            model_name='article',
            name='public',
            field=models.BooleanField(default=True, help_text='Whether the article is completely public.', verbose_name='public'),
        ),
        migrations.AlterField(
            model_name='article',
            name='namespace',
            field=models.CharField(choices=[('srd5', '5th Edition SRD'), ('rivenrock', 'The Rivenrock Wiki')], help_text="The article's namespace.", max_length=255, verbose_name='namespace'),
        ),
    ]
