{% extends 'thorson_wiki/base.html' %}

{% load i18n %}

{% block content %}

<h1>{% trans "List of Articles" %}</h1>

<hr/>

<ul>
  {% for article in object_list %}
    <li><a href="{{ article.get_absolute_url }}">{{ article.title }}</a></li>
  {% endfor %}
</ul>

{% endblock %}
