# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-01-04 22:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text='The title of this article.', max_length=255, verbose_name='title')),
                ('slug', models.SlugField(blank=True, editable=False, help_text="The article's title,  slugified for URLs.", max_length=255, verbose_name='slug')),
                ('namespace', models.CharField(choices=[('rivenrock', 'rivenrock'), ('srd5', 'srd5')], help_text="The article's namespace.", max_length=255, verbose_name='namespace')),
                ('content', models.TextField(blank=True, help_text='The content of the article.', verbose_name='content')),
                ('login_required', models.BooleanField(default=False, help_text='Whether only logged-in users may read the article.', verbose_name='login required')),
                ('redirect', models.CharField(blank=True, help_text='Allows this article to redirect to another one.', max_length=255, verbose_name='redirect to')),
            ],
            options={
                'verbose_name': 'article',
                'verbose_name_plural': 'articles',
            },
        ),
    ]
